@@ -57,9 +57,9 @@ class GetBundleTestCase(unittest.TestCase):
 @mock.patch('git_pw.api.download')
 @mock.patch('git_pw.utils.git_am')
 class ApplyTestCase(unittest.TestCase):
-
-    def test_apply_without_args(self, mock_git_am, mock_download,
-                                mock_get_bundle):
+    def test_apply_without_args(
+        self, mock_git_am, mock_download, mock_get_bundle
+    ):
         """Validate calling with no arguments."""
 
         rsp = {'mbox': 'http://example.com/api/patches/123/mbox/'}
@@ -74,8 +74,9 @@ class ApplyTestCase(unittest.TestCase):
         mock_download.assert_called_once_with(rsp['mbox'])
         mock_git_am.assert_called_once_with(mock_download.return_value, ())
 
-    def test_apply_with_args(self, mock_git_am, mock_download,
-                             mock_get_bundle):
+    def test_apply_with_args(
+        self, mock_git_am, mock_download, mock_get_bundle
+    ):
         """Validate passthrough of arbitrary arguments to git-am."""
 
         rsp = {'mbox': 'http://example.com/api/patches/123/mbox/'}
@@ -88,14 +89,14 @@ class ApplyTestCase(unittest.TestCase):
         assert result.exit_code == 0, result
         mock_get_bundle.assert_called_once_with('123')
         mock_download.assert_called_once_with(rsp['mbox'])
-        mock_git_am.assert_called_once_with(mock_download.return_value,
-                                            ('-3',))
+        mock_git_am.assert_called_once_with(
+            mock_download.return_value, ('-3',)
+        )
 
 
 @mock.patch('git_pw.bundle._get_bundle')
 @mock.patch('git_pw.api.download')
 class DownloadTestCase(unittest.TestCase):
-
     def test_download(self, mock_download, mock_get_bundle):
         """Validate standard behavior."""
 
@@ -124,12 +125,12 @@ class DownloadTestCase(unittest.TestCase):
         mock_get_bundle.assert_called_once_with('123')
         mock_download.assert_called_once_with(rsp['mbox'], output=mock.ANY)
         assert isinstance(
-            mock_download.call_args[1]['output'], str,
+            mock_download.call_args[1]['output'],
+            str,
         )
 
 
 class ShowTestCase(unittest.TestCase):
-
     @staticmethod
     def _get_bundle(**kwargs):
         # Not a complete response but good enough for our purposes
@@ -180,7 +181,6 @@ class ShowTestCase(unittest.TestCase):
 @mock.patch('git_pw.api.index')
 @mock.patch('git_pw.utils.echo_via_pager')
 class ListTestCase(unittest.TestCase):
-
     @staticmethod
     def _get_bundle(**kwargs):
         return ShowTestCase._get_bundle(**kwargs)
@@ -204,9 +204,15 @@ class ListTestCase(unittest.TestCase):
         result = runner.invoke(bundle.list_cmd, [])
 
         assert result.exit_code == 0, result
-        mock_index.assert_called_once_with('bundles', [
-            ('q', None), ('page', None), ('per_page', None),
-            ('order', 'name')])
+        mock_index.assert_called_once_with(
+            'bundles',
+            [
+                ('q', None),
+                ('page', None),
+                ('per_page', None),
+                ('order', 'name'),
+            ],
+        )
 
     def test_list_with_formatting(self, mock_echo, mock_index, mock_version):
         """Validate behavior with formatting applied."""
@@ -215,13 +221,16 @@ class ListTestCase(unittest.TestCase):
         mock_index.return_value = rsp
 
         runner = CLIRunner()
-        result = runner.invoke(bundle.list_cmd, [
-            '--format', 'simple', '--column', 'ID', '--column', 'Name'])
+        result = runner.invoke(
+            bundle.list_cmd,
+            ['--format', 'simple', '--column', 'ID', '--column', 'Name'],
+        )
 
         assert result.exit_code == 0, result
 
-        mock_echo.assert_called_once_with(mock.ANY, ('ID', 'Name'),
-                                          fmt='simple')
+        mock_echo.assert_called_once_with(
+            mock.ANY, ('ID', 'Name'), fmt='simple'
+        )
 
     def test_list_with_filters(self, mock_echo, mock_index, mock_version):
         """Validate behavior with filters applied.
@@ -234,22 +243,45 @@ class ListTestCase(unittest.TestCase):
         mock_index.side_effect = [user_rsp, bundle_rsp]
 
         runner = CLIRunner()
-        result = runner.invoke(bundle.list_cmd, [
-            '--owner', 'john.doe', '--owner', '2', '--limit', 1, '--page', 1,
-            '--sort', '-name', 'test'])
+        result = runner.invoke(
+            bundle.list_cmd,
+            [
+                '--owner',
+                'john.doe',
+                '--owner',
+                '2',
+                '--limit',
+                1,
+                '--page',
+                1,
+                '--sort',
+                '-name',
+                'test',
+            ],
+        )
 
         assert result.exit_code == 0, result
         calls = [
             mock.call('users', [('q', 'john.doe')]),
-            mock.call('bundles', [
-                ('owner', 1), ('owner', '2'), ('q', 'test'), ('page', 1),
-                ('per_page', 1), ('order', '-name')])]
+            mock.call(
+                'bundles',
+                [
+                    ('owner', 1),
+                    ('owner', '2'),
+                    ('q', 'test'),
+                    ('page', 1),
+                    ('per_page', 1),
+                    ('order', '-name'),
+                ],
+            ),
+        ]
 
         mock_index.assert_has_calls(calls)
 
     @mock.patch('git_pw.api.LOG')
-    def test_list_with_wildcard_filters(self, mock_log, mock_echo, mock_index,
-                                        mock_version):
+    def test_list_with_wildcard_filters(
+        self, mock_log, mock_echo, mock_index, mock_version
+    ):
         """Validate behavior with a "wildcard" filter.
 
         Patchwork API v1.0 did not support multiple filters correctly. Ensure
@@ -266,8 +298,9 @@ class ListTestCase(unittest.TestCase):
         assert mock_log.warning.called
 
     @mock.patch('git_pw.api.LOG')
-    def test_list_with_multiple_filters(self, mock_log, mock_echo, mock_index,
-                                        mock_version):
+    def test_list_with_multiple_filters(
+        self, mock_log, mock_echo, mock_index, mock_version
+    ):
         """Validate behavior with use of multiple filters.
 
         Patchwork API v1.0 did not support multiple filters correctly. Ensure
@@ -279,15 +312,17 @@ class ListTestCase(unittest.TestCase):
         mock_index.side_effect = [people_rsp, people_rsp, bundle_rsp]
 
         runner = CLIRunner()
-        result = runner.invoke(bundle.list_cmd, ['--owner', 'john.doe',
-                                                 '--owner', 'user.b'])
+        result = runner.invoke(
+            bundle.list_cmd, ['--owner', 'john.doe', '--owner', 'user.b']
+        )
 
         assert result.exit_code == 0, result
         assert mock_log.warning.called
 
     @mock.patch('git_pw.api.LOG')
-    def test_list_api_v1_1(self, mock_log, mock_echo, mock_index,
-                           mock_version):
+    def test_list_api_v1_1(
+        self, mock_log, mock_echo, mock_index, mock_version
+    ):
         """Validate behavior with API v1.1."""
 
         mock_version.return_value = (1, 1)
@@ -297,10 +332,17 @@ class ListTestCase(unittest.TestCase):
         mock_index.side_effect = [user_rsp, bundle_rsp]
 
         runner = CLIRunner()
-        result = runner.invoke(bundle.list_cmd, [
-            '--owner', 'john.doe',
-            '--owner', 'user.b',
-            '--owner', 'john@example.com'])
+        result = runner.invoke(
+            bundle.list_cmd,
+            [
+                '--owner',
+                'john.doe',
+                '--owner',
+                'user.b',
+                '--owner',
+                'john@example.com',
+            ],
+        )
 
         assert result.exit_code == 0, result
 
@@ -309,10 +351,19 @@ class ListTestCase(unittest.TestCase):
         # usernames natively
         calls = [
             mock.call('users', [('q', 'john@example.com')]),
-            mock.call('bundles', [
-                ('owner', 'john.doe'), ('owner', 'user.b'), ('owner', 1),
-                ('q', None), ('page', None), ('per_page', None),
-                ('order', 'name')])]
+            mock.call(
+                'bundles',
+                [
+                    ('owner', 'john.doe'),
+                    ('owner', 'user.b'),
+                    ('owner', 1),
+                    ('q', None),
+                    ('page', None),
+                    ('per_page', None),
+                    ('order', 'name'),
+                ],
+            ),
+        ]
         mock_index.assert_has_calls(calls)
 
         # We shouldn't see a warning about multiple versions either
@@ -323,7 +374,6 @@ class ListTestCase(unittest.TestCase):
 @mock.patch('git_pw.api.create')
 @mock.patch('git_pw.utils.echo_via_pager')
 class CreateTestCase(unittest.TestCase):
-
     @staticmethod
     def _get_bundle(**kwargs):
         return ShowTestCase._get_bundle(**kwargs)
@@ -339,7 +389,7 @@ class CreateTestCase(unittest.TestCase):
         assert result.exit_code == 0, result
         mock_create.assert_called_once_with(
             'bundles',
-            [('name', 'hello'), ('patches', (1, 2)), ('public', False)]
+            [('name', 'hello'), ('patches', (1, 2)), ('public', False)],
         )
 
     def test_create_with_public(self, mock_echo, mock_create, mock_version):
@@ -348,13 +398,14 @@ class CreateTestCase(unittest.TestCase):
         mock_create.return_value = self._get_bundle()
 
         runner = CLIRunner()
-        result = runner.invoke(bundle.create_cmd, [
-            'hello', '1', '2', '--public'])
+        result = runner.invoke(
+            bundle.create_cmd, ['hello', '1', '2', '--public']
+        )
 
         assert result.exit_code == 0, result
         mock_create.assert_called_once_with(
             'bundles',
-            [('name', 'hello'), ('patches', (1, 2)), ('public', True)]
+            [('name', 'hello'), ('patches', (1, 2)), ('public', True)],
         )
 
     @mock.patch('git_pw.api.LOG')
@@ -376,7 +427,6 @@ class CreateTestCase(unittest.TestCase):
 @mock.patch('git_pw.api.detail')
 @mock.patch('git_pw.utils.echo_via_pager')
 class UpdateTestCase(unittest.TestCase):
-
     @staticmethod
     def _get_bundle(**kwargs):
         return ShowTestCase._get_bundle(**kwargs)
@@ -399,7 +449,11 @@ class UpdateTestCase(unittest.TestCase):
         )
 
     def test_update_with_public(
-        self, mock_echo, mock_detail, mock_update, mock_version,
+        self,
+        mock_echo,
+        mock_detail,
+        mock_update,
+        mock_version,
     ):
         """Validate behavior with --public option."""
 
@@ -414,7 +468,12 @@ class UpdateTestCase(unittest.TestCase):
 
     @mock.patch('git_pw.api.LOG')
     def test_update_api_v1_1(
-        self, mock_log, mock_echo, mock_detail, mock_update, mock_version,
+        self,
+        mock_log,
+        mock_echo,
+        mock_detail,
+        mock_update,
+        mock_version,
     ):
 
         mock_version.return_value = (1, 1)
@@ -430,7 +489,6 @@ class UpdateTestCase(unittest.TestCase):
 @mock.patch('git_pw.api.delete')
 @mock.patch('git_pw.utils.echo_via_pager')
 class DeleteTestCase(unittest.TestCase):
-
     def test_delete(self, mock_echo, mock_delete, mock_version):
         """Validate standard behavior."""
 
@@ -444,7 +502,11 @@ class DeleteTestCase(unittest.TestCase):
 
     @mock.patch('git_pw.api.LOG')
     def test_delete_api_v1_1(
-        self, mock_log, mock_echo, mock_delete, mock_version,
+        self,
+        mock_log,
+        mock_echo,
+        mock_delete,
+        mock_version,
     ):
         """Validate standard behavior."""
 
@@ -462,13 +524,16 @@ class DeleteTestCase(unittest.TestCase):
 @mock.patch('git_pw.api.detail')
 @mock.patch('git_pw.utils.echo_via_pager')
 class AddTestCase(unittest.TestCase):
-
     @staticmethod
     def _get_bundle(**kwargs):
         return ShowTestCase._get_bundle(**kwargs)
 
     def test_add(
-        self, mock_echo, mock_detail, mock_update, mock_version,
+        self,
+        mock_echo,
+        mock_detail,
+        mock_update,
+        mock_version,
     ):
         """Validate standard behavior."""
 
@@ -481,12 +546,19 @@ class AddTestCase(unittest.TestCase):
         assert result.exit_code == 0, result
         mock_detail.assert_called_once_with('bundles', '1')
         mock_update.assert_called_once_with(
-            'bundles', '1', [('patches', (1, 2, 42))],
+            'bundles',
+            '1',
+            [('patches', (1, 2, 42))],
         )
 
     @mock.patch('git_pw.api.LOG')
     def test_add_api_v1_1(
-        self, mock_log, mock_echo, mock_detail, mock_update, mock_version,
+        self,
+        mock_log,
+        mock_echo,
+        mock_detail,
+        mock_update,
+        mock_version,
     ):
         """Validate behavior with API v1.1."""
 
@@ -504,13 +576,16 @@ class AddTestCase(unittest.TestCase):
 @mock.patch('git_pw.api.detail')
 @mock.patch('git_pw.utils.echo_via_pager')
 class RemoveTestCase(unittest.TestCase):
-
     @staticmethod
     def _get_bundle(**kwargs):
         return ShowTestCase._get_bundle(**kwargs)
 
     def test_remove(
-        self, mock_echo, mock_detail, mock_update, mock_version,
+        self,
+        mock_echo,
+        mock_detail,
+        mock_update,
+        mock_version,
     ):
         """Validate standard behavior."""
 
@@ -525,12 +600,19 @@ class RemoveTestCase(unittest.TestCase):
         assert result.exit_code == 0, result
         mock_detail.assert_called_once_with('bundles', '1')
         mock_update.assert_called_once_with(
-            'bundles', '1', [('patches', (3,))],
+            'bundles',
+            '1',
+            [('patches', (3,))],
         )
 
     @mock.patch('git_pw.bundle.LOG')
     def test_remove_empty(
-        self, mock_log, mock_echo, mock_detail, mock_update, mock_version,
+        self,
+        mock_log,
+        mock_echo,
+        mock_detail,
+        mock_update,
+        mock_version,
     ):
         """Validate behavior when deleting would remove all patches."""
 
@@ -549,7 +631,12 @@ class RemoveTestCase(unittest.TestCase):
 
     @mock.patch('git_pw.api.LOG')
     def test_remove_api_v1_1(
-        self, mock_log, mock_echo, mock_detail, mock_update, mock_version,
+        self,
+        mock_log,
+        mock_echo,
+        mock_detail,
+        mock_update,
+        mock_version,
     ):
         """Validate behavior with API v1.1."""
 
